@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: clustal-omega.c 260 2011-09-01 16:10:46Z fabian $
+ *  RCS $Id: clustal-omega.c 268 2011-11-16 02:34:34Z andreas $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -111,9 +111,6 @@
  */
 
 
-
-
-/* FIXME: doc */
 /* the following are temporary flags while the code is still under construction;
    had problems internalising hhmake, so as temporary crutch 
    write alignment to file and get external hmmer/hhmake via system call 
@@ -209,7 +206,8 @@ SetDefaultAlnOpts(opts_t *prOpts) {
     prOpts->bIterationsAuto = FALSE;
     prOpts->iMaxGuidetreeIterations = INT_MAX;
     prOpts->iMaxHMMIterations = INT_MAX;
-    prOpts->iMacRam = 2048; /* give 2GB to MAC algorithm. FS, r240 -> r241 */
+
+    SetDefaultHhalignPara(& prOpts->rHhalignPara);
  }
 /* end of SetDefaultAlnOpts() */
 
@@ -257,12 +255,9 @@ AlnOptsLogicCheck(opts_t *prOpts)
         */
     }
     
-    if (prOpts->iMacRam < 512) {
-
-        Log(&rLog, LOG_INFO, "Memory for MAC Algorithm quite low, Viterbi Algorithm may be triggered.");
-
-        if (prOpts->iMacRam < 1) {
-
+    if (prOpts->rHhalignPara.iMacRamMB < 512) {
+        Log(&rLog, LOG_WARN, "Memory for MAC Algorithm quite low, Viterbi Algorithm may be triggered.");
+        if (prOpts->rHhalignPara.iMacRamMB < 1) {
             Log(&rLog, LOG_WARN, "Viterbi Algorithm always turned on, increase MAC-RAM to turn on MAC.");
         }
     }
@@ -303,6 +298,8 @@ PrintAlnOpts(FILE *prFile, opts_t *prOpts)
 	fprintf(prFile, "option: iterations-auto = %d\n", prOpts->bIterationsAuto);
 	fprintf(prFile, "option: max-hmm-iterations = %d\n", prOpts->iMaxHMMIterations);
 	fprintf(prFile, "option: max-guidetree-iterations = %d\n", prOpts->iMaxGuidetreeIterations);
+    fprintf(prFile, "option: iMacRamMB = %d\n", prOpts->rHhalignPara.iMacRamMB);
+
 }
 /* end of PrintAlnOpts() */
 
@@ -931,8 +928,6 @@ SetAutoOptions(opts_t *prOpts, int iNumSeq) {
  * optional profile to align against
  * @param[in] prOpts
  * alignment options to use
- * @param[in] rHhalignPara
- * FIXME
  *
  * @return 0 on success, -1 on failure
  *
@@ -940,8 +935,7 @@ SetAutoOptions(opts_t *prOpts, int iNumSeq) {
 int
 Align(mseq_t *prMSeq, 
       mseq_t *prMSeqProfile,
-      opts_t *prOpts,
-      hhalign_para rHhalignPara) {
+      opts_t *prOpts) {
    
     /* HMM
      */
@@ -1146,7 +1140,7 @@ Align(mseq_t *prMSeq,
      */
     dAlnScore = HHalignWrapper(prMSeq, piOrderLR, pdSeqWeights,
                                2*prMSeq->nseqs -1/* nodes */,
-                               prHMMs, prOpts->iHMMInputFiles, -1, rHhalignPara);
+                               prHMMs, prOpts->iHMMInputFiles, -1, prOpts->rHhalignPara);
     dLastAlnScore = dAlnScore;
     Log(&rLog, LOG_VERBOSE,
         "Alignment score for first alignment = %f", dAlnScore);        
@@ -1223,6 +1217,7 @@ Align(mseq_t *prMSeq,
                 CKFREE(piOrderLR);
             if (NULL != pdSeqWeights)
                 CKFREE(pdSeqWeights);
+            Log(&rLog, LOG_INFO, "Computing new guide tree (iteration step %d)");
             if (AlignmentOrder(&piOrderLR, &pdSeqWeights, prMSeq,
                                PAIRDIST_SQUIDID_KIMURA /* override */, NULL, prOpts->pcDistmatOutfile,
                                prOpts->iClusteringType, NULL, prOpts->pcGuidetreeOutfile,
@@ -1243,6 +1238,8 @@ Align(mseq_t *prMSeq,
            therefore sanitise unknown characters, FS, r259 -> r260 */
         SanitiseUnknown(prMSeq);
         if (iIterationCounter < prOpts->iMaxHMMIterations) {
+            Log(&rLog, LOG_INFO, "Computing HMM from alignment");
+            
             if (OK !=
 #if INDIRECT_HMM 
                 AlnToHMM(&rHMMLocal, prMSeq)
@@ -1262,7 +1259,8 @@ Align(mseq_t *prMSeq,
         /* align the sequences (again)
          */
         dAlnScore = HHalignWrapper(prMSeq, piOrderLR, pdSeqWeights,
-                                   2*prMSeq->nseqs -1/* nodes */, &rHMMLocal, 1, -1, rHhalignPara);
+                                   2*prMSeq->nseqs -1/* nodes */, &rHMMLocal, 1, -1, 
+                                   prOpts->rHhalignPara);
         Log(&rLog, LOG_VERBOSE,
             "Alignment score for alignmnent in hmm-iteration no %d = %f (last score = %f)",
              iIterationCounter+1, dAlnScore, dLastAlnScore);
@@ -1312,7 +1310,7 @@ Align(mseq_t *prMSeq,
      *
      */
     if (NULL != prMSeqProfile) {
-        if (AlignProfiles(prMSeq, prMSeqProfile, rHhalignPara)) {
+        if (AlignProfiles(prMSeq, prMSeqProfile, prOpts->rHhalignPara)) {
             Log(&rLog, LOG_ERROR, "An error occured during the profile/profile alignment");
             return -1;
         }
