@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign_wrapper.c 267 2011-10-24 09:49:27Z fabian $
+ *  RCS $Id: hhalign_wrapper.c 274 2012-04-24 23:28:24Z dave $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,6 +26,7 @@
 #include <string.h>
 #include <assert.h>
 #include <ctype.h>
+#include <stdbool.h>
 
 #include "seq.h"
 #include "tree.h"
@@ -44,12 +45,14 @@
 /**
  * @brief FIXME
  * 
- * @note prHalignPara has tp point to an already allocated instance
+ * @note prHalignPara has to point to an already allocated instance
  *
  */
 void SetDefaultHhalignPara(hhalign_para *prHhalignPara)
 {
-    prHhalignPara->iMacRamMB = 2048; /* give 2GB to MAC algorithm */
+    prHhalignPara->iMacRamMB = 2048;  /* 2048 default|give 2GB to MAC algorithm */
+    prHhalignPara->bIsDna = false; /* protein mode unless we say otherwise */	
+    prHhalignPara->bIsRna = false;	
 }
 /*** end: SetDefaultHhalignPara()  ***/
 
@@ -539,7 +542,6 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
 #endif
     hhalign_scores rHHscores = {0};
 
-    
     if (NULL != prHMMList) {
         if (iHMMCount>1) {
             Log(&rLog, LOG_WARN, "FIXME: Using only first of %u HMMs (needs implementation)", iHMMCount);
@@ -561,8 +563,12 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
      * protein
      */
     if (SEQTYPE_PROTEIN != prMSeq->seqtype) {
-        Log(&rLog, LOG_WARN, "Sequence type is %s. HHalign has only been tested on protein.",
+        Log(&rLog, LOG_WARN, "%s alignment is still experimental.",
              SeqTypeToStr(prMSeq->seqtype));
+		if(prMSeq->seqtype == SEQTYPE_DNA)
+			rHhalignPara.bIsDna = true;
+		if(prMSeq->seqtype == SEQTYPE_RNA)
+			rHhalignPara.bIsRna = true;
     }
 
     /* hhalign produces funny results if sequences contain gaps, so
