@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: seq.c 270 2011-11-16 07:27:31Z andreas $
+ *  RCS $Id: seq.c 274 2012-04-24 23:28:24Z dave $
  *
  *
  * Module for sequence/alignment IO and misc.
@@ -39,7 +39,7 @@
 #include "seq.h"
 
 
-#define ALLOW_ONLY_PROTEIN 1
+#define ALLOW_ONLY_PROTEIN 0 // DD
 
 
 
@@ -553,12 +553,12 @@ ReadSequences(mseq_t *prMSeq, char *seqfile,
     }
     SeqfileClose(dbfp);
 
-#if ALLOW_ONLY_PROTEIN
+/*#if ALLOW_ONLY_PROTEIN
     if (SEQTYPE_PROTEIN != prMSeq->seqtype) {
         Log(&rLog, LOG_FATAL, "Sequence type is %s. %s only works on protein.",
               SeqTypeToStr(prMSeq->seqtype), PACKAGE_NAME);
     }
-#endif
+#endif*/
     
     /* Check if sequences are aligned */
     prMSeq->aligned = SeqsAreAligned(prMSeq);
