@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- * RCS $Id: general.h 267 2011-10-24 09:49:27Z fabian $
+ * RCS $Id: general.h 274 2012-04-24 23:28:24Z dave $
  */
 
 
@@ -24,6 +24,7 @@
 
 
 #include "../clustal/log.h"
+#include <stdbool.h>
 
 /*
 ***** Omega definitions************************************
@@ -48,6 +49,8 @@ enum {INTERN_ALN_2_HMM = 0, READ_ALN_2_HMM, READ_HMM_2_HMM, INTERN_HMM_2_HMM};
 typedef struct {
 
     int iMacRamMB; /* dedicated amount of RAM for Maximum Accuracy (in MB) */
+	bool bIsDna; /* indicates we're in nucleotide mode */
+	bool bIsRna; /* indicates we're in nucleotide mode */
 
 } hhalign_para;
 
