@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign.cpp 267 2011-10-24 09:49:27Z fabian $
+ *  RCS $Id: hhalign.cpp 274 2012-04-24 23:28:24Z dave $
  */
 
 /* hhalign.C: 
@@ -113,10 +113,7 @@ float** Pstruc=NULL;   /* structure matrix which can be multiplied to prob
 			  ratios from aa column comparisons in Forward() */
 float** Sstruc=NULL;   /* structure matrix which can be added to log odds 
 			  from aa column comparisons in Forward() */
-
-
-
-
+bool nucleomode = false;
 
 ////////////////////////////////////////////////////////////////////////////
 // Help functions
@@ -847,8 +844,21 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
     
     
     // Set (global variable) substitution matrix and derived matrices
-    SetSubstitutionMatrix();
-    
+	// DD: new experimental matrices and params for nucleotides
+	if(rHhalignPara.bIsDna)
+	{
+		nucleomode = true;
+		SetDnaDefaults();
+		SetDnaSubstitutionMatrix();
+	}
+	else if(rHhalignPara.bIsRna)
+	{
+		nucleomode = true;
+		SetRnaDefaults();
+		SetRnaSubstitutionMatrix();
+	}	
+	else
+		SetSubstitutionMatrix();
     
     // Set secondary structure substitution matrix
     SetSecStrucSubstitutionMatrix();
@@ -899,7 +909,6 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
 
     }
     
-    
     // Read input file (HMM, HHM, or alignment format), and add pseudocounts etc.
     q.cQT = 'q';
     if (OK != ReadAndPrepare(INTERN_ALN_2_HMM,
@@ -1017,10 +1026,11 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
   /* Do (self-)comparison, store results if score>SMIN, 
      and try next best alignment */
   /* FIXME very ambigous and possibly faulty if-else */
-  if (v>=2) {
-      if (par.forward==2) {
-          printf("Using maximum accuracy (MAC) alignment algorithm ...\n");
-      }
+  if (v>=2)
+  {
+    if (par.forward==2) {
+        printf("Using maximum accuracy (MAC) alignment algorithm ...\n");
+    }
     else if (par.forward==0) {
         printf("Using Viterbi algorithm ...\n");
     }
@@ -1304,11 +1314,15 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
   rHHscores->hhScore     = hit.score; 
   rHHscores->forwardProb = hit.Pforward;
   rHHscores->sumPP       = hit.sum_of_probs;
-  rHHscores->PP = (double *)malloc((hit.L+GOOD_MEASURE) * sizeof(double));
+
+  /* next few lines commented out as they caused segfaults in RNA mode */
+  /*  rHHscores->PP = (double *)malloc((hit.L+GOOD_MEASURE) * sizeof(double));*/
   rHHscores->L  = hit.L;
-  for (int i = 0; i < hit.L; i++){
+/*  for (int i = 0; i < hit.L; i++){
+      cout << "rHHscores->PP[i]" << rHHscores->PP[i] << endl;
+      cout << "hit.P_posterior[i+1]" << hit.P_posterior[i+1] << endl;
       rHHscores->PP[i] = hit.P_posterior[i+1];
-  }
+  } */
 
 
  this_is_the_end: 
