@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- * RCS $Id: hhalign.h 241 2011-05-04 14:37:17Z fabian $
+ * RCS $Id: hhalign.h 267 2011-10-24 09:49:27Z fabian $
  */
 
 
@@ -25,6 +25,6 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
         double *dScore_p, hmm_light *prHMM, 
         char *pcPrealigned1, char *pcRepresent1,
         char *pcPrealigned2, char *pcRepresent2,
-        hhalign_para rHhalignPara,
+        hhalign_para rHhalignPara, hhalign_scores *rHHscores, 
         int iFlag,
         char zcAux[], char zcError[]);
