@@ -15,14 +15,15 @@
  ********************************************************************/
 
 /*
- * RCS $Id: hhutil-C.h 246 2011-06-15 12:41:04Z fabian $
+ * RCS $Id: hhutil-C.h 274 2012-04-24 23:28:24Z dave $
  */
 
+extern bool nucleomode;
+ 
 //////////////////////////////////////////////////////////////////////////////
 // Transform a character to lower case and '.' to '-' and vice versa
 //////////////////////////////////////////////////////////////////////////////
 
-
 inline char 
 MatchChr(char c)  {return ((c>='a' && c<='z')? c-'a'+'A' : (c=='.'? '-':c) );}
 
@@ -40,40 +41,61 @@ WordChr(char c) {return (int)((c>='A' && c<='Z') || (c>='a' && c<='z'));}
 inline char 
 aa2i(char c)
 {
-  //A  R  N  D  C  Q  E  G  H  I  L  K  M  F  P  S  T  W  Y  V
   if (c>='a' && c<='z') c+='A'-'a';
-  switch (c)
-    {
+  if(!nucleomode)
+  {	  
+	  // proteins!
+	  // A  R  N  D  C  Q  E  G  H  I  L  K  M  F  P  S  T  W  Y  V
+	  switch (c)
+		{
+		case 'A': return 0;
+		case 'R': return 1;
+		case 'N': return 2;
+		case 'D': return 3;
+		case 'C': return 4;
+		case 'Q': return 5;
+		case 'E': return 6;
+		case 'G': return 7;
+		case 'H': return 8;
+		case 'I': return 9;
+		case 'L': return 10;
+		case 'K': return 11;
+		case 'M': return 12;
+		case 'F': return 13;
+		case 'P': return 14;
+		case 'S': return 15;
+		case 'T': return 16;
+		case 'W': return 17;
+		case 'Y': return 18;
+		case 'V': return 19;
+		case 'X': return ANY;
+		case 'J': return ANY;
+		case 'O': return ANY;
+		case 'U': return 4;  //Selenocystein -> Cystein
+		case 'B': return 3;  //D (or N)
+		case 'Z': return 6;  //E (or Q)
+		case '-': return GAP;
+		case '.': return GAP;
+		case '_': return GAP;
+		}
+  }
+  else
+  {
+		// nucleotides!
+	switch(c)
+	{
     case 'A': return 0;
-    case 'R': return 1;
-    case 'N': return 2;
-    case 'D': return 3;
-    case 'C': return 4;
-    case 'Q': return 5;
-    case 'E': return 6;
-    case 'G': return 7;
-    case 'H': return 8;
-    case 'I': return 9;
-    case 'L': return 10;
-    case 'K': return 11;
-    case 'M': return 12;
-    case 'F': return 13;
-    case 'P': return 14;
-    case 'S': return 15;
-    case 'T': return 16;
-    case 'W': return 17;
-    case 'Y': return 18;
-    case 'V': return 19;
-    case 'X': return ANY;
-    case 'J': return ANY;
-    case 'O': return ANY;
-    case 'U': return 4;  //Selenocystein -> Cystein
-    case 'B': return 3;  //D (or N)
-    case 'Z': return 6;  //E (or Q)
+    case 'C': return 1;
+    case 'G': return 2;
+    case 'T': return 3;
+    case 'U': return 4;
+    case 'N': return ANY;
     case '-': return GAP;
     case '.': return GAP;
     case '_': return GAP;
-    }
+	default: return ANY;
+	}
+  }
   if (c>=0 && c<=32) return -1; // white space and control characters
   return -2;
 }
@@ -86,6 +108,8 @@ inline char
 i2aa(char c)
 {
   //A  R  N  D  C  Q  E  G  H  I  L  K  M  F  P  S  T  W  Y  V
+  if(!nucleomode)
+  {
   switch (c)
     {
     case 0: return 'A';
@@ -112,6 +136,22 @@ i2aa(char c)
     case GAP: return '-';
     case ENDGAP: return '-';
     }
+  }
+  else
+  {
+	// DNA/RNA
+	switch(c)
+	{
+		case 0: return 'A';
+		case 1: return 'C';
+		case 2: return 'G';
+		case 3: return 'T';
+		case 4: return 'U';
+		case ANY: return 'N';
+		case GAP: return '-';
+		case ENDGAP: return '-';
+	}
+  }
   return '?';
 }
 
@@ -543,7 +583,7 @@ SetDefaults()
 
   par.matrix=0;                // Subst.matrix 0: Gonnet, 1: HSDM, 2: BLOSUM50 3: BLOSUM62 
   par.pcm=2;                   // pseudocount mode: default=divergence-dependent (but not column-specific)
-#if 1 /* Nelder-Meade on Baliscore */
+#if 1 /* Nelder-Meade on Baliscore*/
   par.pca=1.712190f;                // default values for substitution matrix pseudocounts 
   par.pcb=1.039640f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
   par.pcc=0.878067f;                // pcs are reduced prop. to 1/Neff^pcc
@@ -598,7 +638,7 @@ SetDefaults()
   par.gapfV=0.151634;                // factor for increasing gap open penalty for deletes
   par.gapgV=0.641516;                // factor for increasing gap open penalty for inserts
   par.gaphV=0.266434;                // factor for increasing gap extension penalty for deletes
-  par.gapiV=0.598414;                // factor for increasing gap extension penalty for inserts
+  par.gapiV=0.598414;                // factor for increasing gap extension penalty for inserts 
 #else /* Soeding default*/ 
   par.pcaV=1.0f;                // default values for substitution matrix pseudocounts 
   par.pcbV=1.5f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
@@ -662,13 +702,67 @@ SetDefaults()
   strcpy(par.psifile,""); 
   par.exclstr=NULL; 
 
-#if 0  /* read parameter file from home-dir */
-#include "hhutil-C-help.h"
-#endif /* read parameter file from home-dir */
-
    return;
 } /** this is the end of SetDefaults() **/
 
+void SetRnaDefaults()
+{
+  par.pca=1.28f;                // default values for substitution matrix pseudocounts 
+  par.pcb=1.75f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
+  par.pcc=0.87f;                // pcs are reduced prop. to 1/Neff^pcc
+  par.pcw=0.0f;                // wc>0 weighs columns according to their intra-clomun similarity
+
+  par.gapb=0.80;                // default values for transition pseudocounts
+  par.gapd=0.34;               // gap open penalty pseudocount; 0.25 corresponds to 7.1*gapf bits
+  par.gape=2.25;                // gap extension penalty pseudocount
+  par.gapf=0.51;                // factor for increasing gap open penalty for deletes
+  par.gapg=1.01;                // factor for increasing gap open penalty for inserts
+  par.gaph=1.24;                // factor for increasing gap extension penalty for deletes
+  par.gapi=0.45;                // factor for increasing gap extension penalty for inserts
+  
+  par.pcaV=2.57f;                // default values for substitution matrix pseudocounts 
+  par.pcbV=2.34f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
+  par.pccV=0.88f;                // pcs are reduced prop. to 1/Neff^pcc
+  par.pcwV=0.0f;                // wc>0 weighs columns according to their intra-clomun similarity
+
+  par.gapbV=1.41;                // default values for transition pseudocounts
+  par.gapdV=1.8;               // gap open penalty pseudocount; 0.25 corresponds to 7.1*gapf bits
+  par.gapeV=1.5;                // gap extension penalty pseudocount
+  par.gapfV=1.03;                // factor for increasing gap open penalty for deletes
+  par.gapgV=0.89;                // factor for increasing gap open penalty for inserts
+  par.gaphV=0.54;                // factor for increasing gap extension penalty for deletes
+  par.gapiV=0.86;                // factor for increasing gap extension penalty for inserts  
+}
+
+void SetDnaDefaults()
+{
+  par.pca=2.89f;                // default values for substitution matrix pseudocounts 
+  par.pcb=1.17f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
+  par.pcc=0.88f;                // pcs are reduced prop. to 1/Neff^pcc
+  par.pcw=0.0f;                // wc>0 weighs columns according to their intra-clomun similarity
+
+  par.gapb=0.80;                // default values for transition pseudocounts
+  par.gapd=0.34;               // gap open penalty pseudocount; 0.25 corresponds to 7.1*gapf bits
+  par.gape=2.25;                // gap extension penalty pseudocount
+  par.gapf=0.78;                // factor for increasing gap open penalty for deletes
+  par.gapg=1.01;                // factor for increasing gap open penalty for inserts
+  par.gaph=1.24;                // factor for increasing gap extension penalty for deletes
+  par.gapi=0.45;                // factor for increasing gap extension penalty for inserts
+  
+  par.pcaV=1.712f;                // default values for substitution matrix pseudocounts 
+  par.pcbV=1.039f;                // significant reduction of pcs by Neff_M starts around Neff_M-1=pcb
+  par.pccV=0.266f;                // pcs are reduced prop. to 1/Neff^pcc
+  par.pcwV=0.0f;                // wc>0 weighs columns according to their intra-clomun similarity
+
+  par.gapbV=1.405;                // default values for transition pseudocounts
+  par.gapdV=1.8;               // gap open penalty pseudocount; 0.25 corresponds to 7.1*gapf bits
+  par.gapeV=2.25;                // gap extension penalty pseudocount
+  par.gapfV=1.034;                // factor for increasing gap open penalty for deletes
+  par.gapgV=2.025;                // factor for increasing gap open penalty for inserts
+  par.gaphV=0.544;                // factor for increasing gap extension penalty for deletes
+  par.gapiV=1.35;                // factor for increasing gap extension penalty for inserts }
+}
+
 /*
  * EOF hhutil-C.h
  */
