@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: mymain.c 270 2011-11-16 07:27:31Z andreas $
+ *  RCS $Id: mymain.c 274 2012-04-24 23:28:24Z dave $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -305,14 +305,11 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
     struct arg_file *opt_profile2 = arg_file0(NULL, "profile2,p2",
                                               "<file>",
                                               "Pre-aligned multiple sequence file (aligned columns will be kept fix)");
-#if 0
     struct arg_str *opt_seqtype = arg_str0("t", "seqtype",
                                            "{Protein, RNA, DNA}",
                                            "Force a sequence type (default: auto)");
-#else
-    struct arg_lit *opt_force_protein = arg_lit0(NULL, "protein",
-                                         "Set sequence type to protein even if Clustal guessed nucleic acid");
-#endif
+/*    struct arg_lit *opt_force_protein = arg_lit0(NULL, "protein",
+                                         "Set sequence type to protein even if Clustal guessed nucleic acid"); */
     struct arg_str *opt_infmt = arg_str0(NULL, "infmt",
                                             "{a2m=fa[sta],clu[stal],msf,phy[lip],selex,st[ockholm],vie[nna]}",
                                             "Forced sequence input file format (default: auto)");
@@ -410,12 +407,8 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
                         opt_dealign,
                         opt_profile1,
                         opt_profile2,
-#if 0
-                        /* unused since we only support protein for now */
                         opt_seqtype,
-#else
-                        opt_force_protein,
-#endif
+                        /* opt_force_protein, */
                         opt_infmt,
                         rem_guidetree,
 #if 0
@@ -620,7 +613,6 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
 
     /* Sequence type
      */
-#if 0
     if (opt_seqtype->count > 0) {
         if (STR_NC_EQ(opt_seqtype->sval[0], "protein")) {
             user_opts->iSeqType = SEQTYPE_PROTEIN;
@@ -632,11 +624,9 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
             Log(&rLog, LOG_FATAL, "Unknown sequence type '%s'", opt_seqtype->sval[0]);
         }
     }
-#else
-    if (opt_force_protein->count > 0) {
+/*    if (opt_force_protein->count > 0) {
         user_opts->iSeqType = SEQTYPE_PROTEIN;
-    }
-#endif
+    } */
 
     /* Profile input
      */
